@@ -37,9 +37,10 @@ use backend::Protection;
 use backend::utils::Directory;
 
 mod certd;
+
 // XXX: openpgp-card-sequoia is deprecated.  We've copied what we
 // need, but we should fork it.
-#[allow(unused)]
+#[cfg(test)]
 mod privkey;
 
 #[derive(Clone)]
@@ -342,7 +343,7 @@ impl BackendInternal {
                 // Convert from an
                 // openpgp_card::ocard::data::Fingerprint to a
                 // sequoia_openpgp::Fingerprint.
-                let fpr = Fingerprint::from_bytes(fpr.as_bytes());
+                let fpr = Fingerprint::from_bytes(4, fpr.as_bytes())?;
                 log::trace!("{}: {}present",
                             fpr, if present { "" } else { "NOT " });
 
@@ -948,8 +949,7 @@ impl backend::KeyHandle for Key {
                 #[allow(non_snake_case)]
                 let S: Protected = dec.into();
 
-                #[allow(deprecated)]
-                Ok(ecdh::decrypt_unwrap(&public_key, &S, ciphertext)?)
+                Ok(ecdh::decrypt_unwrap(&public_key, &S, ciphertext, None /* XXX */)?)
             }
 
             (ciphertext, public) => Err(anyhow::anyhow!(
@@ -1140,6 +1140,7 @@ impl backend::KeyHandle for Key {
 mod tests {
     use super::*;
 
+    use openpgp::KeyHandle;
     use openpgp::cert::amalgamation::key::ValidKeyAmalgamation;
     use openpgp::parse::Parse;
     use openpgp::policy::StandardPolicy;
@@ -1151,7 +1152,8 @@ mod tests {
 
     use backend::Backend as _;
 
-    const TEST_CARD_ID: &str = "0005:0000AB6D";
+    /// This is the ID and PINs for the opcard-rs virtual smart card.
+    const TEST_CARD_ID: &str = "0000:00000000";
     const TEST_CARD_ADMIN_PIN: &str = "12345678";
     const TEST_CARD_USER_PIN: &str = "123456";
 
@@ -1239,7 +1241,7 @@ mod tests {
         eprintln!("Importing cert {}'s subkeys", cert.fingerprint());
         for ka in vc.keys().subkeys() {
             eprintln!("  - {}, secret: {}, key flags: {:?}",
-                      ka.fingerprint(), ka.has_secret(), ka.key_flags());
+                      ka.key().fingerprint(), ka.key().has_secret(), ka.key_flags());
         }
 
         let signing_key
@@ -1272,9 +1274,9 @@ mod tests {
         let mut import_key = |key: Option<ValidKeyAmalgamation<_, _, ()>>, slot: KeyType| {
             if let Some(key) = key {
                 eprintln!("Importing key {} to {:?} slot",
-                          key.fingerprint(), slot);
+                          key.key().fingerprint(), slot);
 
-                assert!(key.has_unencrypted_secret());
+                assert!(key.key().has_unencrypted_secret());
                 let key = Box::new(privkey::SequoiaKey::new(key.into(), None));
                 //let key = openpgp_card_sequoia::util::vka_as_uploadable_key(
                 //    key.into(), None);
